/*******************************************************************************
*
*            USING THE ADC IN SINGLE CONVERSION MODE
*            ---------------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   5. December 2010
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*   Description:            This programm is a simple example hwo to use the
*                           ATMEGA16 ADC in single conversion mode. AVCC is used
*                           as referencevoltage and ADC4 is selected by the input
*                           mux. The voltage  is measured single ended. The
*                           output of the conversion is compared with 512 and a
*                           digitalport shows the relust.
*                           No interrupt is used,the programm waits until the
*                           conversion is finished. 
*                           
*   What you can learn:     - Select AVCC as ADC voltagereference
*                           - Select an ADC clockprescaler
*                           - Select an ADC input with the ADC MUX 
*                           - Enable the ADC
*                           - Start a single Conversion
*                           - Wait wait for the end of the
*                             conversion (without interrupt)
*                           - Read and use the result
*
*   Clock source:           - Any 1MHz clock
*
*   Recommended             - High: 0x99
*   Fuse settings:          - Low:  0xE1
*
*
*
*   Schematic:       ___________________
*                   |      ATMEGA16     |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |              AREF |----
*          GND ---->|GND                |   |
*                   |                   |  ===
*          Vcc      |                   |   |
*           |       |                   |  GND
*           |       |                   |             
*          |P|      |                   |
*     10k  |O|      |                   |
*          |T|----->| PA4 (ADC4)        |             
*          |I|      |                   |
*           |       |                   |
*           |       |               PB0 |----> DOUT     
*          GND      |                   |
*
*******************************************************************************/


#include <avr/io.h>

int main(void)
{

    DDRB = 0x01;                       // Setup PB0 as output

    
    ADMUX |= (1<<REFS0)|(1<<MUX2);    // Set Reference to AVCC and input to ADC4
    ADCSRA |= (1<<ADEN)|(1<<ADPS2);   // Enable ADC, set prescaler to 16
                                      // Fadc=Fcpu/prescaler=1000000/16=62.5kHz
                                      // Fadc should be between 50kHz and 200kHz



  
  
    for(;;)                         // Endless loop;
    {

        ADCSRA |= (1<<ADSC);        // Start a conversion
        while(ADCSRA & (1<<ADSC));  // What until the bit is reset by the
                                    // CPU after the conversion is finished

        if(ADC>=512)                // Compare the conversionresult with 512
            PORTB |= 0x01;          // If larger, set PB0
        else
            PORTB &= ~0x01;         // If smaller, reset PB0

    }                               // main() will never be left




    return 0;                       // This line will never be executed

}


